@@ -1,10 +1,12 @@
 
-use strict;
 package Mail::Box::MH;
 use vars '$VERSION';
-$VERSION = '2.062';
+$VERSION = '2.064';
 use base 'Mail::Box::Dir';
 
+use strict;
+use filetest 'access';
+
 use Mail::Box::MH::Index;
 use Mail::Box::MH::Message;
 use Mail::Box::MH::Labels;
@@ -208,7 +210,7 @@ sub appendMessages(@)
                  : exists $args{messages} ? @{$args{messages}}
                  : return ();
 
-    my $self     = $class->new(@_, access => 'a')
+    my $self     = $class->new(@_, access => 'r')
         or return ();
 
     my $directory= $self->directory;
@@ -231,10 +233,11 @@ sub appendMessages(@)
         $msgnr++;
     }
  
-    my $labels   = $self->labels->append(@messages);
+    $self->labels->append(@messages);
+    $self->index->append(@messages);
 
     $locker->unlock;
-    $self->close;
+    $self->close(write => 'NEVER');
 
     @messages;
 }
@@ -282,7 +285,7 @@ sub labels()
     $self->{MBM_labels} = $self->{MBM_labels_type}->new
       ( filename => $self->{MBM_labels_filename}
       , $self->logSettings
-      )
+      );
 }
 
 #-------------------------------------------
