@@ -4,7 +4,7 @@ use warnings;
 
 package Mail::Message::Convert::MailInternet;
 use vars '$VERSION';
-$VERSION = '2.063';
+$VERSION = '2.064';
 use base 'Mail::Message::Convert';
 
 use Mail::Internet;
@@ -40,7 +40,7 @@ sub export($@)
 
 
 my @pref_order = qw/From To Cc Subject Date In-Reply-To References
-    Content-Type Lines Content-Length/;
+    Content-Type/;
 
 sub from($@)
 {   my ($thing, $mi) = (shift, shift);
